import { decodeKeyVault, deriveKeyVault, encodeKeyVault, type KeyVault } from "./crypto";

export function loggedIn() {
    if (typeof window !== 'object') return false;
    return !!sessionStorage['_vault'];
}

export async function login(passkey: string): Promise<KeyVault> {
    const keyVault = await deriveKeyVault(passkey);
    sessionStorage['_vault'] = encodeKeyVault(keyVault);
    return keyVault;
}

export function getKeyVault(): KeyVault | null {
    try {
        return decodeKeyVault(sessionStorage['_vault']);
    } catch (e) {
        console.log(e);
        return null;
    }
}

export function logout() {
    delete sessionStorage['_vault'];
}

