import { convertVideo } from "$lib/ffmpeg.server";
import { error } from "@sveltejs/kit";
import type { RequestHandler } from "./$types";
import { hexToUint8, verify } from "$lib/crypto";

export const POST: RequestHandler = async ({ request, url }) => {
    const pubkeyHex = url.searchParams.get('pubkey')?.trim()?.toLowerCase();
    if (!pubkeyHex || !/^[0-9a-f]{64}$/.test(pubkeyHex)) error(400);
    const pubKey = hexToUint8(pubkeyHex);

    const signatureHex = url.searchParams.get('signature')?.trim()?.toLowerCase();
    if (!signatureHex || !/^[0-9a-f]+$/.test(signatureHex)) error(400);
    const signature = hexToUint8(signatureHex);

    const bodyBuffer = await request.arrayBuffer();
    const bodyUint8 = new Uint8Array(bodyBuffer);
    
    const valid = await verify(pubKey, signature, bodyUint8);
    if (!valid) error(401);

    const convertedUint8 = await convertVideo(bodyUint8);
    if (!convertedUint8) error(500);

    return new Response(convertedUint8, {
        headers: {
			'Content-Type': 'video/mp4',
        },
    });
}
