import { error, text } from "@sveltejs/kit";
import type { RequestHandler } from "./$types";
import { DeleteObjectCommand } from "@aws-sdk/client-s3";
import { env } from "$env/dynamic/private";
import { s3 } from "$lib/storage.server";
import { hexToUint8, strToUint8, verify } from "$lib/crypto";

export const POST: RequestHandler = async ({ request, url }) => {
    const dateStr = url.searchParams.get('date')?.trim()?.toLowerCase();
    if (!dateStr || !/^[0-9]{4}-[0-9]{2}-[0-9]{2}$/.test(dateStr)) error(400);
    const date = new Date(dateStr);

    const msDiff = new Date().getTime() - date.getTime() + 36 * 60 * 60 * 1000;
    if (msDiff <= 0) error(400);

    const pubkeyHex = url.searchParams.get('pubkey')?.trim()?.toLowerCase();
    if (!pubkeyHex || !/^[0-9a-f]{64}$/.test(pubkeyHex)) error(400);
    const pubKey = hexToUint8(pubkeyHex);

    const signatureHex = url.searchParams.get('signature')?.trim()?.toLowerCase();
    if (!signatureHex || !/^[0-9a-f]+$/.test(signatureHex)) error(400);
    const signature = hexToUint8(signatureHex);

    const valid = await verify(pubKey, signature, strToUint8(dateStr));
    if (!valid) error(401);

    const command = new DeleteObjectCommand({
        Bucket: env.S3_BUCKET,
        Key: `${pubkeyHex}/${dateStr}`,
    });

    await s3.send(command);

    return text('ok');
}
